pytilities.types.numbertype — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.types »

# pytilities.types.numbertype

class `pytilities.types.numbertype.` `NumberType`

  Represents any number type.

  Ints, floats and infinity are subclasses of this class.

  `__weakref__`

    list of weak references to the object (if defined)

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.types »